# frozen_string_literal: true

require 'ext/string'

require 'retryable'

require 'steam/id'

# Require Steam Language from the steamd gem
require 'steamd'
Steamd.load_language

# Require any protobufs we care about from the steam-proto gem
require 'steam/proto'
Steam::Proto.load_protobufs(:steamclient, :gc)

require 'stringio'

require 'steam/version'
require 'steam/logger'
require 'steam/crypto'
require 'steam/sentry_file'
require 'steam/byte_reader'
require 'steam/byte_writer'
require 'steam/protocol'
require 'steam/server'
require 'steam/server_list'
require 'steam/networking'
require 'steam/handler'
require 'steam/plugins'
require 'steam/client'
require 'steam/local_ip'
require 'steam/emsg_util'

# Ruby access to Steam
module Steam
  # Logger object. Logs to the given IO object. Defaults to STDOUT
  #
  # @param io [:read] the io stream
  # @return [Steam::Logger]
  def self.logger(io = STDOUT)
    @logger ||= Steam::Logger.new(io)
  end
end
