# frozen_string_literal: true
module Steam
  # Utility to provide EMsg convenience. Allows looking up
  # EMsg name by the EMsg integer value.
  #
  # @example Getting an EMsg name from its value
  #   EMsgUtil.new(123).name # => 'SOME_EMSG'
  class EMsgUtil
    # Instantiate the object
    #
    # @param emsg [Integer] the integer emsg value
    def initialize(emsg)
      @emsg = emsg
    end

    # Return the name of the EMsg
    #
    # @return [String]
    def name
      emsg.to_s
    end

    private

    # @api private
    def emsg
      EMsg.constants.select { |x| EMsg.const_get(x) == @emsg }.first
    end
  end
end
