# frozen_string_literal: true
require 'socket'
require 'ipaddr'

module Steam
  # Access to the Local IP
  #
  # @example Get Local IP
  #   ip = LocalIp.new
  #   ip.to_s # => '192.168.1.158'
  #   ip.to_i # => 3232235934
  class LocalIp
    def initialize
      @addr = Socket.ip_address_list.detect(&:ipv4_private?)
    end

    # Get the IP address as a string
    #
    # @return [String] the ip
    def to_s
      @addr.ip_address
    end
    alias address to_s

    # Get the IP address as a int
    #
    # @return [Integer] the ip
    def to_i
      IPAddr.new(address).to_i
    end
  end
end
