# frozen_string_literal: true
module Steam
  module Networking
    # Holds a list of Packet objects in a non-blocking thread safe queue
    class PacketList
      def initialize
        @packets = Thread::Queue.new
      end

      # Adds a Packet to the internal queue
      #
      # @param packet [Packet] the Packet to add
      def add(packet)
        @packets.push(packet)
      end

      # Removes the next message
      #
      # @return [Packet] The Packet object
      def pop
        @packets.pop(true)
      rescue ThreadError
        nil
      end
    end
  end
end
