# frozen_string_literal: true
module Steam
  # Represents a Sentry file on disk
  #
  # @todo this will overwrite any existing file, namespace
  #   to username?
  class SentryFile
    # Writes the digest to the sentry file
    #
    # @example Write the SentryFile
    #   file = SentryFile.new
    #   file.write('sha1digest')
    #
    # @param digest [String]
    def write(digest)
      File.open(path, 'wb') do |file|
        file.write(digest)
      end
    end

    # Read the digest from the sentry file. Returns
    # nil if the Sentry file does not exist.
    #
    # @example Read the SentryFile
    #   file = SentryFile.new
    #   file.read # => 'somedigest'
    #
    # @return [String,nil]
    def read
      return nil unless File.exist?(path)

      File.open(path, 'rb', &:read)
    end

    private

    # @api private
    def path
      '/tmp/.steam-sentry'
    end
  end
end
